Maximum likelihood estimation for the zero-inflated Poisson distribution with Poisson parameter lambda and zero proportion prop.zero.
Source:R/estimate_zipoisson.R
estimate_zi_poisson.RdGiven data, computes the maximum likelihood estimators for the zero-inflated Poisson distribution.